/**
  ******************************************************************************
  * @file           : main.c
  * @author         : sinomcu.com-AE
  * @brief          : Main program body
  *    
  *          This file provides example code for USART multi communication master;
  * eg two slave;baud rate and slave address in file user_config.h.vritual UART for
  * printf ,LED1 blink by sysTick soft timer,LED blink period 1S.
  * For details, see "readme.txt"   
  *         
  ******************************************************************************
   * @attention 
  *                           DISCLAIMER
  * The present firmware which is for guidance only aims at providing customers
  * with coding information regarding their products in order for them to save
  * time. As a result, sinomcu.com shall not be held liable for any direct,indirect
  * or consequential damages with respect to any claims arising from the content 
  * of such firmware and/or the use made by customers of the coding information 
  * contained herein in connection with their products.
  *
  * <h2><center>&copy; Copyright (c) 2021 sinomcu.com All rights reserved.</center></h2>
  *
  ******************************************************************************
  */  
  
#include "system_define.h"

#define LED_BLINK_HALF_PER        500       // unit ms,LED blink half cycle

UartRecvStatus recv_status = WAIT_STAR;
UartRecvFinishFlag recv_finsh = NO_FINISH;
uint8_t g_uartRecvBuff[FRAME_LEN]={0};

uint8_t g_slaveIDBuff[SLAVE_NUM]={SLAVE1_ADD, SLAVE2_ADD };

/**
  * @brief  Main program
  * @param  None
  * @retval None
  */
int main(void) 
{
  uint32_t LED_blink_Time = LED_BLINK_HALF_PER;
  uint32_t count=0;
  
  sysclk_init();                  //sysclk 48M,HSI/2 *12;if not call this function,default HSI 8M
  SystemCoreClockUpdate();
  
  sys_tick_init();
  gpio_init();
  usart1_multi_init(BAUD_RATE);
  virtualUart_Init();

  LED1_ON(); 
  
  printf("\r\n\r\n*****UART Multi Master*****");
  printf("\r\n--Inf:System Core Clock %d Hz.\r\n",SystemCoreClock);
  
  Start_User_MS_SF_Timer(LED_blink_Time);
  while(1) {
    if(recv_finsh == FINISH) {
      recv_finsh = FINISH_CLR;
      LED_blink_Time =LED_BLINK_HALF_PER;
      printf("%s",g_uartRecvBuff);                                                         // recv one frame,send back
    }

    if(Get_State_User_MS_SF_Timer() == SF_TIMER_OV) {
      Start_User_MS_SF_Timer(LED_blink_Time);         // clear soft timer ov
      Loop_OneSlave(g_slaveIDBuff[count++ % SLAVE_NUM]);
      
      LED1_TOGGLE();                                  // led blink for running
    }
  }
}

/**
  * @brief  SystemClock_Config HSI/2 to PLL*12 sysclk 48M
  * @param  None
  * @retval None
  */
void sysclk_init(void) {
  MS32_RCC_OscInitTypeDef osc_cfg;
  MS32_RCC_PllInitTypeDef pll_cfg;
  MS32_RCC_ClkInitTypeDef clk_cfg;

  // get and clear reset flag 
  MS32_RCC_GetResetFlag(ENABLE);
  
  // osc config 
  osc_cfg.HSIState = MS32_RCC_HSI_ON;
  osc_cfg.HSEState = MS32_RCC_HSE_OFF;
  osc_cfg.LSIState = MS32_RCC_LSI_OFF;
//  osc_cfg.LSEState = MS32_RCC_LSE_ON_DRV_H;
  MS32_RCC_OscConfig(&osc_cfg);
  
  // pll config 
  pll_cfg.PLLState  = MS32_RCC_PLL_ON;
  pll_cfg.PLLSource = MS32_RCC_PLL_SOURCE_HSI_DIV_2;  // HSI/2 4M
  pll_cfg.PLLMUL    = MS32_RCC_PLL_MUL12;
  pll_cfg.PREDIV    = MS32_RCC_PLL_PREDIV_DIV1;
  MS32_RCC_PllConfig(&pll_cfg);
  
  // sysclk config 
  clk_cfg.SYSCLKSource   = MS32_RCC_SYSCLK_SOURCE_PLL;
  clk_cfg.AHBCLKDivider  = MS32_RCC_SYSCLK_DIV1;
  clk_cfg.APB1CLKDivider = MS32_RCC_HCLK_DIV1;
  MS32_RCC_ClockConfig(&clk_cfg);
}
/******************************** END OF FILE *********************************/
