/**
  ******************************************************************************
  * @file    UART_User.h
  * @author  sinomcu.com-AE
  * @brief   Header file of UART_User.c file.
  * 
  *          This file describes the macro definitions used:
  *     RS485_DATA_LEN,FRAME_START_CHAR,FRAME_END_CHAR
  *     typedef UartRecvStatus, UartRecvFinishFlag;
  * 
  ******************************************************************************
  * @attention 
  *                           DISCLAIMER
  * The present firmware which is for guidance only aims at providing customers
  * with coding information regarding their products in order for them to save
  * time. As a result, sinomcu.com shall not be held liable for any direct,indirect
  * or consequential damages with respect to any claims arising from the content 
  * of such firmware and/or the use made by customers of the coding information 
  * contained herein in connection with their products.
  *
  * <h2><center>&copy; Copyright (c) 2021 sinomcu.com All rights reserved.</center></h2>
  *
  ******************************************************************************
 */

#ifndef __UART_USER_H
#define __UART_USER_H

#include "ms32f0xx.h"

#define FRAME_LEN            16        /* uart buff len,byte */
#define FRAME_START_CHAR     '$'       /* frame start char */
#define FRAME_END_CHAR       0x0A      /* frame end char */ 

typedef enum {
  WAIT_STAR = 0U,
  RECV_ING,
  RECV_FIN,                            /* WAIT_STAR,RECV_ING,RECV_FIN:for state machine */
  UART_ERROR_ORE,
  UART_ERROR_NIOSE,
  UART_ERROR_NO_DEF,
  UART_ERROR_CLR                       /* UART_ERROR_xxx:for reg flag bit */
} UartRecvStatus;

typedef enum {
  FINISH = 0U,
  NO_FINISH,
  FINISH_CLR,
  RECV_ERROR,
  RECV_ERROR_CLR                       /* receive process state machine */
} UartRecvFinishFlag;

void USART_RXNE_Callback(void);
void Loop_OneSlave(uint8_t slave_id);

#endif /* __UART_USER_H */ 

/******************************** END OF FILE ******************************** */
