/**
  ******************************************************************************
  * @file     UART_user.c
  * @author   sinomcu.com-AE
  * @brief    
  *         
  ******************************************************************************
  * @attention 
  *                           DISCLAIMER
  * The present firmware which is for guidance only aims at providing customers
  * with coding information regarding their products in order for them to save
  * time. As a result, sinomcu.com shall not be held liable for any direct,indirect
  * or consequential damages with respect to any claims arising from the content 
  * of such firmware and/or the use made by customers of the coding information 
  * contained herein in connection with their products.
  *
  * <h2><center>&copy; Copyright (c) 2021 sinomcu.com All rights reserved.</center></h2>
  *
  ******************************************************************************
 */

#include "ms32f0xx.h"
#include "user_config.h"
#include "USART1_CFG.h"
#include "UART_User.h"
#include "Virtual_UART.h"

extern UartRecvStatus recv_status;
extern UartRecvFinishFlag recv_finsh;

extern UartRecvStatus recv_status;
extern UartRecvFinishFlag recv_finsh;
extern uint8_t g_uartRecvBuff[];

/**
  * @brief  Function called from USART IRQ Handler when RXNE set.
  *         Reading character received on USART RX and store data to receive buffer if data match frame format
  *         frame format:$…… \r\n,lengh max FRAME_LEN.
  * @param  None
  * @retval None
 */
void USART_RXNE_Callback(void) {
  __IO uint32_t received_char;
  static uint8_t recv_count=0,recv_temp_count=0;

  /* Read Received character. RXNE flag is cleared by reading of RDR register */ 
  received_char = MS32_USART_ReceiveData9(USART1);

  if(received_char == FRAME_START_CHAR) {                  /* $, recv data to buff */
    recv_status = RECV_ING;
    recv_finsh = NO_FINISH;
    recv_count =0;recv_temp_count=0;
    g_uartRecvBuff[recv_count++] =received_char;
  }
  else if(recv_status == RECV_ING) {                       /* had recv $,data to buff */
    g_uartRecvBuff[recv_count++] =received_char;
    if((received_char == FRAME_END_CHAR) || (recv_count >= FRAME_LEN)) {       /* recv 0x0A or had recv buff len,end recv */
      g_uartRecvBuff[recv_count] ='\0';
      recv_count =0;
      recv_status = RECV_FIN;
      recv_finsh = FINISH;
    }
  }
  else {                                                   /* have't recv $,data discard */
    recv_status =  WAIT_STAR;
    recv_temp_count++;
    if((received_char == FRAME_END_CHAR) || (recv_temp_count >= FRAME_LEN)) {  /* recv 0x0A or had recv buff len,end recv */
      recv_finsh = RECV_ERROR;
      recv_temp_count=0;
    }
  }
}

/**
  * @brief  send buff to uart,end with chat '\0'
  * @param  pointer of send buff,uint8_t ptr
  * @retval None
 */
void UART_SendBuff(uint8_t *sendBuff) {
  uint8_t send_count = 0;
  uint16_t sendData9bit=0;

  for(; sendBuff[send_count] !='\0';) {     /* str end by '\0' */
    if(MS32_USART_IsActiveFlag_TC(USART1)) {
      block_delayUs(ONE_BIT_DELAY_US); 
      sendData9bit =sendBuff[send_count++];
      MS32_USART_TransmitData9(USART1, sendData9bit); 
    }
    if(send_count > FRAME_LEN) {                      /* also end by max len */
      break;
    }
  }
  while(!(MS32_USART_IsActiveFlag_TC(USART1))){ ; }        /* wait TC set */
}

/******************************** END OF FILE ******************************** */
